import { jsx, jsxs } from 'react/jsx-runtime';
import MuiTypography from '@mui/material/Typography';
import { styled } from '@mui/material/styles';
export { StyledEngineProvider, ThemeProvider, styled, useTheme } from '@mui/material/styles';
import React, { forwardRef } from 'react';
import MuiButton from '@mui/material/Button';
import MuiBox from '@mui/material/Box';
import '@mui/material/Breadcrumbs';
import * as react from '@phosphor-icons/react';
export { react as Icon };
import { Box as Box$1, Typography as Typography$1, createTheme } from '@mui/material';
export * from '@mui/material';
import '@fontsource/nunito-sans/400.css';
import '@fontsource/nunito-sans/600.css';
import '@fontsource/nunito-sans/700.css';
import '@fontsource/nunito-sans/800.css';

var hexToRgba = (hex, opacity) => {
    hex = hex.replace(/^#/, '');
    if (hex.length !== 6) {
        throw new Error('Invalid hex color format');
    }
    const r = parseInt(hex.substring(0, 2), 16);
    const g = parseInt(hex.substring(2, 4), 16);
    const b = parseInt(hex.substring(4, 6), 16);
    const alpha = opacity / 100;
    return `rgba(${r},${g},${b},${alpha})`;
};

const fontWeightMapping = {
    regular: 400,
    medium: 600,
    semiBold: 700,
    bold: 800,
};
const TypographyRoot = styled(MuiTypography, {
    shouldForwardProp: (prop) => {
        return prop !== 'weight';
    },
}) `
  font-weight: ${({ weight }) => weight ? fontWeightMapping[weight] : 'inherit'};
`;
const Typography = forwardRef(({ children, weight = 'regular', component, ...otherProps }, ref) => (jsx(TypographyRoot, { component: component, weight: weight, ref: ref, ...otherProps, children: children })));

var PaletteColors;
(function (PaletteColors) {
    PaletteColors["collageRed"] = "collageRed";
    PaletteColors["collageYellow"] = "collageYellow";
    PaletteColors["collageOrange"] = "collageOrange";
    PaletteColors["collagePurple"] = "collagePurple";
    PaletteColors["collageTeal"] = "collageTeal";
    PaletteColors["collageGreen"] = "collageGreen";
    PaletteColors["uiBlue"] = "uiBlue";
    PaletteColors["uiCoolGray"] = "uiCoolGray";
    PaletteColors["uiWhite"] = "uiWhite";
    PaletteColors["uiGray"] = "uiGray";
    PaletteColors["uiGreen"] = "uiGreen";
    PaletteColors["uiYellow"] = "uiYellow";
    PaletteColors["uiRed"] = "uiRed";
})(PaletteColors || (PaletteColors = {}));
var StreamlineIcons;
(function (StreamlineIcons) {
    StreamlineIcons["Lightbulb"] = "lightbulb";
    StreamlineIcons["PerformanceIncrease"] = "performance_increase";
    StreamlineIcons["Like"] = "like";
    StreamlineIcons["ShoppingBasket"] = "shopping_basket";
})(StreamlineIcons || (StreamlineIcons = {}));

const mapVariantToMui = (variant) => {
    switch (variant) {
        case 'primary':
        case 'secondary':
            return 'contained';
        case 'tertiary':
            return 'outlined';
        case 'text':
        case 'link':
        case 'nav':
            return 'text';
        default:
            return 'contained';
    }
};
const getDefaultColor = (variant) => {
    switch (variant) {
        case 'primary':
        case 'secondary':
            return PaletteColors.collageRed;
        case 'tertiary':
        case 'text':
        case 'nav':
            return PaletteColors.uiGray;
        case 'link':
            return PaletteColors.uiBlue;
        default:
            return PaletteColors.collageRed;
    }
};
const ButtonForwardRef = React.forwardRef(({ customVariant: _customVariant, customColor: _customColor, ...props }, ref) => jsx(MuiButton, { ref: ref, ...props }));
const ButtonRoot = styled(ButtonForwardRef)(({ theme, customVariant, size, customColor }) => {
    const mainColor = customColor ?? getDefaultColor(customVariant);
    return {
        display: 'flex',
        fontSize: 16,
        padding: '8px, 16px',
        textAlign: 'center',
        borderRadius: 4,
        alignItems: 'center',
        boxShadow: 'none',
        textTransform: 'none',
        justifyContent: 'center',
        minHeight: 0,
        whiteSpace: 'nowrap',
        ...(size === 'small' && {
            fontSize: '14px',
            padding: '4px 12px',
        }),
        ...(size === 'medium' && {
            fontSize: '16px',
            padding: '8px 16px',
        }),
        ...(size === 'large' && {
            fontSize: '18px',
            padding: '12px 20px',
        }),
        ...(customVariant === 'primary' && {
            color: theme.palette.uiWhite[500],
            backgroundColor: theme.palette[mainColor][400],
            height: '40px',
            '&:hover': {
                backgroundColor: theme.palette[mainColor][500],
            },
        }),
        ...(customVariant === 'secondary' && {
            color: theme.palette[mainColor][500],
            border: '1px solid',
            borderColor: theme.palette[mainColor][200],
            backgroundColor: theme.palette.uiWhite[500],
            height: '40px',
            '&:hover': {
                backgroundColor: theme.palette[mainColor][50],
                borderColor: theme.palette[mainColor][500],
            },
        }),
        ...(customVariant === 'tertiary' && {
            color: theme.palette[mainColor][800],
            border: '1px solid',
            borderColor: theme.palette[mainColor][200],
            backgroundColor: theme.palette.uiWhite[500],
            height: '40px',
            '&:hover': {
                backgroundColor: theme.palette.uiCoolGray[50],
                borderColor: theme.palette[mainColor][500],
            },
        }),
        ...(customVariant === 'text' && {
            padding: '2px 4px',
            color: theme.palette[mainColor][800],
            '&:hover': {
                background: 'none',
                border: 'none',
                color: theme.palette.collageRed[600],
            },
        }),
        ...(customVariant === 'link' && {
            color: theme.palette[mainColor][600],
            background: 'none',
            padding: '2px 4px',
            borderRadius: 0,
            minWidth: 0,
            '&:hover': {
                ':after': {
                    content: '""',
                    background: theme.palette[mainColor][600],
                    position: 'absolute',
                    bottom: -2,
                    left: '0',
                    height: '1px',
                    width: '100%',
                },
                background: 'none',
            },
            '&:active': {
                background: 'none',
                border: 'none',
                borderRadius: '4px',
                ':after': {
                    content: '""',
                    background: 'none',
                },
            },
        }),
        ...(customVariant === 'nav' && {
            color: theme.palette[mainColor][800],
            background: 'none',
            padding: '2px 4px',
            '&:hover': {
                backgroundColor: theme.palette.uiCoolGray[50],
            },
            '&:active': {
                color: theme.palette.collageRed[500],
                backgroundColor: theme.palette.collageRed[50],
            },
        }),
        '&:disabled': {
            ...(customVariant === 'primary' && {
                backgroundColor: theme.palette.uiCoolGray[100],
                color: theme.palette.uiCoolGray[300],
            }),
            ...(customVariant === 'secondary' && {
                border: '1px solid',
                borderColor: theme.palette.uiCoolGray[100],
                color: theme.palette.uiCoolGray[300],
                backgroundColor: 'transparent',
            }),
            ...(customVariant === 'tertiary' && {
                backgroundColor: 'transparent',
                color: theme.palette.uiCoolGray[300],
                border: 'none',
            }),
        },
    };
});
const Button = React.forwardRef(({ children, variant = 'primary', size = 'medium', color, ...props }, ref) => {
    const muiVariant = mapVariantToMui(variant);
    return (jsx(ButtonRoot, { ref: ref, variant: muiVariant, customVariant: variant, customColor: color, size: size, ...props, children: children }));
});

const Box = forwardRef((props, ref) => jsx(MuiBox, { ...props, ref: ref }));

const Wrapper = styled(Box$1)({
    borderRadius: '4px',
    display: 'flex',
    flexDirection: 'column',
    flex: '1',
});
const HeaderStyled = styled(Box$1)(({ theme }) => ({
    borderRadius: '4px 4px 0px 0px',
    backgroundColor: theme.palette.uiWhite[500],
    display: 'flex',
    alignItems: 'center',
    justifyContent: 'space-between',
    padding: '16px 24px',
    borderBottom: `1px solid ${theme.palette.uiCoolGray[200]}`,
    minHeight: '48px',
}));
const BodyStyled = styled(Box$1)(({ theme }) => ({
    borderRadius: '0px 0px 4px 4px',
    display: 'flex',
    flexDirection: 'column',
    padding: '24px',
    backgroundColor: theme.palette.uiWhite[500],
}));
const CardHeader = forwardRef(({ title, description, actions, sx, ...rest }, ref) => (jsxs(HeaderStyled, { ref: ref, sx: sx, ...rest, children: [jsxs(Box$1, { children: [jsx(Typography$1, { variant: "h1", children: title }), description && (jsx(Typography$1, { variant: "b1", color: "textSecondary", children: description }))] }), actions && jsx(Box$1, { children: actions })] })));
const CardBody = forwardRef(({ sx, children, ...rest }, ref) => (jsx(BodyStyled, { ref: ref, sx: sx, ...rest, children: children })));
const BaseCard = forwardRef(({ children, ...rest }, ref) => (jsx(Wrapper, { ref: ref, ...rest, children: children })));
BaseCard.Header = CardHeader;
BaseCard.Body = CardBody;
BaseCard.displayName = 'BaseCard';

forwardRef(({ withHeader = false, ...restBoxProps }, ref) => {
    const dynamicStyles = {
        display: 'flex',
        flexDirection: 'column',
        justifyContent: 'space-between',
        padding: '40px',
        paddingTop: withHeader ? '160px' : '0px',
        width: '100%',
    };
    return jsx(Box, { ...restBoxProps, sx: dynamicStyles, ref: ref });
});

styled(Box) `
  display: flex;
  justify-content: space-between;
  width: 100%;
  margin-top: 32px;
  gap: 32px;
  flex-wrap: wrap;
`;

const ui = {
    blue: {
        50: '#e7f0f6',
        100: '#b3d1e3',
        200: '#8ebad5',
        300: '#5b9bc2',
        400: '#3b87b6',
        500: '#0a69a4',
        600: '#096095',
        700: '#074b74',
        800: '#063a5a',
        900: '#042c45',
    },
    green: {
        50: '#e8f4ed',
        100: '#b7ddc8',
        200: '#95ccad',
        300: '#64b587',
        400: '#46a770',
        500: '#18914c',
        600: '#168445',
        700: '#116736',
        800: '#0d502a',
        900: '#0a3d20',
    },
    yellow: {
        50: '#fdf5eb',
        100: '#f8e1c0',
        200: '#f5d2a2',
        300: '#f1be77',
        400: '#eeb15d',
        500: '#ea9e34',
        600: '#d5902f',
        700: '#a67025',
        800: '#81571d',
        900: '#624216',
    },
    red: {
        50: '#faebeb',
        100: '#efc0c0',
        200: '#e8a1a1',
        300: '#dd7676',
        400: '#d65c5c',
        500: '#cc3333',
        600: '#ba2e2e',
        700: '#912424',
        800: '#701c1c',
        900: '#561515',
    },
    gray: {
        50: '#efefef',
        100: '#cccccc',
        200: '#b4b4b4',
        300: '#929292',
        400: '#7d7d7d',
        500: '#5c5c5c',
        600: '#545454',
        700: '#414141',
        800: '#333333',
        900: '#272727',
    },
    coolGray: {
        50: '#f2f3f5',
        100: '#d7dbe0',
        200: '#c4cad1',
        300: '#a9b1bb',
        400: '#98a2ae',
        500: '#7e8b9a',
        600: '#737e8c',
        700: '#59636d',
        800: '#454c55',
        900: '#353a41',
    },
    white: {
        500: '#FFFFFF',
    },
    black: {
        500: '#000000',
    },
};

const collage = {
    red: {
        50: '#f2e8eb',
        100: '#d6b7c2',
        200: '#c295a4',
        300: '#a7647a',
        400: '#954661',
        500: '#7b1839',
        600: '#701634',
        700: '#571128',
        800: '#440d1f',
        900: '#340a18',
    },
    yellow: {
        50: '#f9f5ed',
        100: '#ebe0c8',
        200: '#e2d1ae',
        300: '#d4bd89',
        400: '#ccb072',
        500: '#bf9c4f',
        600: '#ae8e48',
        700: '#886f38',
        800: '#69562b',
        900: '#504221',
    },
    orange: {
        50: '#faf0ed',
        100: '#efd2c8',
        200: '#e8bcae',
        300: '#dd9d89',
        400: '#d68a72',
        500: '#cc6d4f',
        600: '#ba6348',
        700: '#914d38',
        800: '#703c2b',
        900: '#562e21',
    },
    purple: {
        50: '#f4eff5',
        100: '#ddcce1',
        200: '#cdb3d3',
        300: '#b690bf',
        400: '#a87bb2',
        500: '#925a9f',
        600: '#855291',
        700: '#684071',
        800: '#503257',
        900: '#3d2643',
    },
    teal: {
        50: '#ebf4f6',
        100: '#c0dee2',
        200: '#a1ced4',
        300: '#76b7c1',
        400: '#5ca9b5',
        500: '#3394a2',
        600: '#2e8793',
        700: '#246973',
        800: '#1c5159',
        900: '#153e44',
    },
    green: {
        50: '#edf3ef',
        100: '#c6dbcc',
        200: '#aacab4',
        300: '#83b191',
        400: '#6ba27c',
        500: '#468b5b',
        600: '#407e53',
        700: '#326341',
        800: '#274c32',
        900: '#1d3a26',
    },
};

const themeColors = {
    primary: {
        main: '#954661',
        dark: '#7b1839',
        light: '#a7647a',
    },
    secondary: {
        main: '#c16f8b',
        dark: '#b14b6e',
        light: '#cb869e',
    },
    error: {
        main: '#CC3333',
        light: '#d65c5c',
        dark: '#ba2e2e',
    },
    warning: {
        main: '#d5902f',
        light: '#ea9e34',
        dark: '#a67025',
    },
    success: {
        main: '#18914c',
        light: '#46a770',
        dark: '#168445',
    },
    text: {
        primary: '#333333',
        secondary: '#5c5c5c',
        disabled: '#b4b4b4',
    },
};

const pxToRem = createTheme().typography.pxToRem;
const capitalize = (text) => {
    return text.charAt(0).toUpperCase() + text.slice(1);
};
const generatePalette = (swatch, name) => {
    const palette = {};
    for (const color in swatch) {
        const colorKey = `${name}${capitalize(color)}`;
        palette[colorKey] = {
            ...swatch[color],
        };
    }
    // NOTE: ex. { 'uiYellow': { '50': '#fdf5eb', '100': '#f8e1c0' } }
    return palette;
};
const palette = {
    ...generatePalette(ui, 'ui'),
    ...generatePalette(collage, 'collage'),
    mode: 'light',
    ...themeColors,
    background: {
        default: ui.coolGray[50],
    },
    defaultColors: {
        black: '#000000',
        white: '#ffffff',
    },
};
const themeOptions = {
    palette,
    typography: {
        allVariants: {
            fontFamily: "'Nunito Sans', sans-serif",
        },
        fontFamily: "'Nunito Sans', sans-serif",
        fontSize: 16,
        h4: undefined,
        h5: undefined,
        h6: undefined,
        subtitle1: undefined,
        subtitle2: undefined,
        body1: undefined,
        body2: undefined,
        button: undefined,
        overline: undefined,
        h1: {
            fontSize: pxToRem(28),
            lineHeight: pxToRem(38),
        },
        h2: {
            fontSize: pxToRem(24),
            lineHeight: pxToRem(33),
        },
        h3: {
            fontSize: pxToRem(20),
            lineHeight: pxToRem(27),
        },
        b1: {
            fontSize: pxToRem(16),
            lineHeight: pxToRem(22),
        },
        b2: {
            fontSize: pxToRem(14),
            lineHeight: pxToRem(19),
        },
        b3: {
            fontSize: pxToRem(12),
            lineHeight: pxToRem(16),
        },
        caption: {
            fontSize: pxToRem(10),
            lineHeight: pxToRem(20),
        },
    },
    components: {
        MuiTypography: {
            styleOverrides: {
                root: {
                    fontWeight: 'unset',
                },
            },
            defaultProps: {
                fontFamily: "'Nunito Sans', sans-serif",
                // NOTE: by default, new variants will render as span
                variantMapping: {
                    b1: 'p',
                    b2: 'p',
                    b3: 'p',
                },
            },
        },
        MuiButtonBase: {
            defaultProps: {
                disableRipple: true,
            },
        },
        MuiButton: {
            styleOverrides: {
                root: {
                    '&:hover': {
                        boxShadow: 'none',
                    },
                },
            },
        },
        MuiCssBaseline: {
            styleOverrides: {
                html: {
                    fontFamily: "'Nunito Sans', sans-serif",
                },
                body: {
                    fontFamily: "'Nunito Sans', sans-serif",
                },
                'svg text': {
                    fontFamily: "'Nunito Sans', sans-serif",
                },
            },
        },
    },
};
const theme = createTheme(themeOptions);

export { Box, Button, PaletteColors, StreamlineIcons, Typography, collage, hexToRgba, palette, theme, themeColors, ui };
//# sourceMappingURL=index.js.map
